# 一些常用的类、方法

#### 介绍
一些常用的类、方法，不定时更新

#### 软件架构
```commandline
 db 是数据库此操作模块
 timeHelper 是和时间相关函数
 common是 一些常用的方法
```


#### 安装教程

```commandline
安装
pip install jyhelper
更新
pip install jyhelper -U
```

#### 使用说明

```python3
from jyhelper import db
from jyhelper import timeHelper
from jyhelper import common

dbIns = db(host='',user='root',password='',port=3306,db='')
for row in dbIns.table('table').select():
    print(row)

print(common.explodeList([1,2,3],2))

print(timeHelper.getDate())
```